@@ -1,9 +1,10 @@
-/* $Id: expense.c,v 1.70 2010-03-03 11:59:39 rousseau Exp $ */
+/* $Id: expense.c,v 1.73 2010-04-13 15:54:02 rikster5 Exp $ */
 
 /*******************************************************************************
  * expense.c
  *
- * This is an example plugin for J-Pilot to demonstrate the plugin API.
+ * This is a plugin for J-Pilot which implements an interface to the
+ * Palm Expense application.
  *
  * Copyright (C) 1999 by Judd Montgomery
  *
@@ -1661,7 +1662,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
                       GTK_SIGNAL_FUNC(cb_delete),
                       GINT_TO_POINTER(DELETE_FLAG));
    
-   CREATE_BUTTON(copy_record_button, _("Copy"), COPY, _("Copy the selected record"), GDK_o, GDK_CONTROL_MASK, "Ctrl+O");
+   CREATE_BUTTON(copy_record_button, _("Copy"), COPY, _("Copy the selected record"), GDK_c, GDK_CONTROL_MASK|GDK_SHIFT_MASK, "Ctrl+Shift+C")
    gtk_signal_connect(GTK_OBJECT(copy_record_button), "clicked",
                       GTK_SIGNAL_FUNC(cb_add_new_record), 
                       GINT_TO_POINTER(COPY_FLAG));
@@ -2080,6 +2081,7 @@ int plugin_search(const char *search_string, int case_sense, struct search_resul
          free_Expense(&(mexp.ex));
       }
    }
+   jp_free_DB_records(&records);
 
    return count;
 }
