@@ -1,8 +1,11 @@
-/* $Id: synctime.c,v 1.14 2008/06/18 02:40:02 rikster5 Exp $ */
+/* $Id: synctime.c,v 1.17 2010-03-29 05:44:32 rikster5 Exp $ */
 
 /*******************************************************************************
  * synctime.c
  *
+ * This is a plugin for J-Pilot which sets the time on the handheld
+ * to the current time of the desktop.
+ *
  * Copyright (C) 1999 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +23,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
@@ -30,16 +34,26 @@
 #include "libplugin.h"
 #include "i18n.h"
 
+/********************************* Constants **********************************/
+#define PLUGIN_MAJOR 1
+#define PLUGIN_MINOR 0
+
+/****************************** Main Code *************************************/
 void plugin_version(int *major_version, int *minor_version)
 {
-   *major_version=0;
-   *minor_version=99;
+   *major_version = PLUGIN_MAJOR;
+   *minor_version = PLUGIN_MINOR;
+}
+
+static int static_plugin_get_name(char *name, int len)
+{
+   snprintf(name, len, "SyncTime %d.%d", PLUGIN_MAJOR, PLUGIN_MINOR);
+   return EXIT_SUCCESS;
 }
 
 int plugin_get_name(char *name, int len)
 {
-   strncpy(name, "SyncTime 0.99", len);
-   return EXIT_SUCCESS;
+   return static_plugin_get_name(name, len);
 }
 
 int plugin_get_help_name(char *name, int len)
@@ -50,15 +64,22 @@ int plugin_get_help_name(char *name, int len)
 
 int plugin_help(char **text, int *width, int *height)
 {
-   *text = strdup(
-	   /*-------------------------------------------*/
-	   _("SyncTime plugin for J-Pilot was written by\n"
-	     "Judd Montgomery (c) 1999.\n"
-	     "judd@jpilot.org\n"
-	     "http://jpilot.org\n"
-	     "\n"
-	     "SyncTime WILL NOT work with PalmOS 3.3!"
-	   ));
+   char plugin_name[200];
+
+   static_plugin_get_name(plugin_name, sizeof(plugin_name));
+   *text = g_strdup_printf(
+      /*-------------------------------------------*/
+      _("%s\n"
+        "\n"
+        "SyncTime plugin for J-Pilot was written by\n"
+        "Judd Montgomery (c) 1999.\n"
+        "judd@jpilot.org\n"
+        "http://jpilot.org\n"
+        "\n"
+        "SyncTime WILL NOT work with PalmOS 3.3!"
+        ),
+        plugin_name
+      );
    *height = 0;
    *width = 0;
    return EXIT_SUCCESS;
@@ -83,9 +104,9 @@ int plugin_sync(int sd)
 
    if (majorVersion==3) {
       if ((minorVersion==30) || (minorVersion==25)) {
-	 jp_logf(JP_LOG_GUI, _("synctime: Palm OS Version 3.25 and 3.30 do not support SyncTime\n"));
-	 jp_logf(JP_LOG_GUI, _("synctime: NOT setting the time on the pilot\n"));
-	 return EXIT_FAILURE;
+         jp_logf(JP_LOG_GUI, _("synctime: Palm OS Version 3.25 and 3.30 do not support SyncTime\n"));
+         jp_logf(JP_LOG_GUI, _("synctime: NOT setting the time on the pilot\n"));
+         return EXIT_FAILURE;
       }
    }
 
