@@ -1,4 +1,4 @@
-/* $Id: category.c,v 1.35 2010-03-03 12:09:43 rousseau Exp $ */
+/* $Id: category.c,v 1.36 2010-03-29 05:44:27 rikster5 Exp $ */
 
 /*******************************************************************************
  * category.c
@@ -80,9 +80,9 @@ static int count_records_in_cat(char *db_name, int cat_index)
 
    for (temp_list = records; temp_list; temp_list = temp_list->next) {
       if (temp_list->data) {
-	 br=temp_list->data;
+         br=temp_list->data;
       } else {
-	 continue;
+         continue;
       }
 
       if (!br->buf) continue;
@@ -122,32 +122,32 @@ static int edit_cats_delete_cats_pc3(char *DB_name, int cat)
    while (!feof(pc_in)) {
       num = read_header(pc_in, &header);
       if (num!=1) {
-	 if (ferror(pc_in)) break;
-	 if (feof(pc_in)) break;
+         if (ferror(pc_in)) break;
+         if (feof(pc_in)) break;
       }
 
       rec_len = header.rec_len;
       if (rec_len > 0x10000) {
-	 jp_logf(JP_LOG_WARN, _("PC file corrupt?\n"));
-	 fclose(pc_in);
-	 return EXIT_FAILURE;
+         jp_logf(JP_LOG_WARN, _("PC file corrupt?\n"));
+         fclose(pc_in);
+         return EXIT_FAILURE;
       }
       if (((header.rt==NEW_PC_REC) || (header.rt==REPLACEMENT_PALM_REC)) &&
-	  ((header.attrib&0x0F)==cat)) {
-	 if (fseek(pc_in, -(header.header_len), SEEK_CUR)) {
-	    jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
-	    fclose(pc_in);
-	    return EXIT_FAILURE;
-	 }
-	 header.rt=DELETED_PC_REC;
-	 write_header(pc_in, &header);
-	 count++;
+          ((header.attrib&0x0F)==cat)) {
+         if (fseek(pc_in, -(header.header_len), SEEK_CUR)) {
+            jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
+            fclose(pc_in);
+            return EXIT_FAILURE;
+         }
+         header.rt=DELETED_PC_REC;
+         write_header(pc_in, &header);
+         count++;
       }
       /* Skip this record now that we are done with it */
       if (fseek(pc_in, rec_len, SEEK_CUR)) {
-	 jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
-	 fclose(pc_in);
-	 return EXIT_FAILURE;
+         jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
+         fclose(pc_in);
+         return EXIT_FAILURE;
       }
    }
 
@@ -158,8 +158,8 @@ static int edit_cats_delete_cats_pc3(char *DB_name, int cat)
 /* Helper routine to change categories.
  * Function changes category regardless of record type */
 static int _edit_cats_change_cats_pc3(char *DB_name, 
-                               int old_cat, int new_cat, 
-                               int swap)
+                                      int old_cat, int new_cat, 
+                                      int swap)
 {
    char local_pc_file[FILENAME_MAX];
    FILE *pc_in;
@@ -180,42 +180,42 @@ static int _edit_cats_change_cats_pc3(char *DB_name,
    while (!feof(pc_in)) {
       num = read_header(pc_in, &header);
       if (num!=1) {
-	 if (ferror(pc_in)) break;
-	 if (feof(pc_in))   break;
+         if (ferror(pc_in)) break;
+         if (feof(pc_in))   break;
       }
       rec_len = header.rec_len;
       if (rec_len > 0x10000) {
-	 jp_logf(JP_LOG_WARN, _("PC file corrupt?\n"));
-	 fclose(pc_in);
-	 return EXIT_FAILURE;
+         jp_logf(JP_LOG_WARN, _("PC file corrupt?\n"));
+         fclose(pc_in);
+         return EXIT_FAILURE;
       }
 
       current_cat = header.attrib & 0x0F;
       if (current_cat==old_cat) {
-	 if (fseek(pc_in, -(header.header_len), SEEK_CUR)) {
-	    jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
-	    fclose(pc_in);
-	    return EXIT_FAILURE;
-	 }
-	 header.attrib=(header.attrib&0xFFFFFFF0) | new_cat;
-	 write_header(pc_in, &header);
-	 count++;
+         if (fseek(pc_in, -(header.header_len), SEEK_CUR)) {
+            jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
+            fclose(pc_in);
+            return EXIT_FAILURE;
+         }
+         header.attrib=(header.attrib&0xFFFFFFF0) | new_cat;
+         write_header(pc_in, &header);
+         count++;
       }
       if ((swap) && (current_cat==new_cat)) {
-	 if (fseek(pc_in, -(header.header_len), SEEK_CUR)) {
-	    jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
-	    fclose(pc_in);
-	    return EXIT_FAILURE;
-	 }
-	 header.attrib=(header.attrib&0xFFFFFFF0) | old_cat;
-	 write_header(pc_in, &header);
-	 count++;
+         if (fseek(pc_in, -(header.header_len), SEEK_CUR)) {
+            jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
+            fclose(pc_in);
+            return EXIT_FAILURE;
+         }
+         header.attrib=(header.attrib&0xFFFFFFF0) | old_cat;
+         write_header(pc_in, &header);
+         count++;
       }
       /* Skip the rest of the record now that we are done with it */
       if (fseek(pc_in, rec_len, SEEK_CUR)) {
-	 jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
-	 fclose(pc_in);
-	 return EXIT_FAILURE;
+         jp_logf(JP_LOG_WARN, _("fseek failed - fatal error\n"));
+         fclose(pc_in);
+         return EXIT_FAILURE;
       }
    }
 
@@ -256,27 +256,27 @@ int edit_cats_change_cats_pdb(char *DB_name, int old_cat, int new_cat)
 
    for (temp_list = records; temp_list; temp_list = temp_list->next) {
       if (temp_list->data) {
-	 br=temp_list->data;
+         br=temp_list->data;
       } else {
-	 continue;
+         continue;
       }
 
       if (!br->buf) continue;
       if ((br->rt==DELETED_PALM_REC) || (br->rt==MODIFIED_PALM_REC)) continue;
 
       if ((br->attrib & 0x0F) == old_cat) {
-	 if (new_cat==-1) {
-	    /* write a deleted rec */
-	    jp_delete_record(DB_name, br, DELETE_FLAG);
-	    count++;
-	 } else {
-	    /* write a deleted rec */
-	    br->attrib=(br->attrib&0xFFFFFFF0) | (new_cat&0x0F);
-	    jp_delete_record(DB_name, br, MODIFY_FLAG);
-	    br->rt=REPLACEMENT_PALM_REC;
-	    jp_pc_write(DB_name, br);
-	    count++;
-	 }
+         if (new_cat==-1) {
+            /* write a deleted rec */
+            jp_delete_record(DB_name, br, DELETE_FLAG);
+            count++;
+         } else {
+            /* write a deleted rec */
+            br->attrib=(br->attrib&0xFFFFFFF0) | (new_cat&0x0F);
+            jp_delete_record(DB_name, br, MODIFY_FLAG);
+            br->rt=REPLACEMENT_PALM_REC;
+            jp_pc_write(DB_name, br);
+            count++;
+         }
       }
    }
 
@@ -291,7 +291,9 @@ int edit_cats_change_cats_pdb(char *DB_name, int old_cat, int new_cat)
  * option will also change new_index records to old_index ones.
  * Returns the number of records where the category was changed.
  */
-static int _change_cat_pdb(char *DB_name, int old_index, int new_index, int swap)
+static int _change_cat_pdb(char *DB_name, 
+                           int old_index, int new_index, 
+                           int swap)
 {
    char local_pdb_file[FILENAME_MAX];
    char full_local_pdb_file[FILENAME_MAX];
@@ -345,11 +347,11 @@ static int _change_cat_pdb(char *DB_name, int old_index, int new_index, int swap
    count = 0;
    while((pi_file_read_record(pf1, idx, &record, &size, &attr, &cat, &uid)) > 0) {
       if (cat==old_index) {
-	 cat=new_index;
-	 count++;
+         cat=new_index;
+         count++;
       } else if ((swap) && (cat==new_index)) {
-	 cat=old_index;
-	 count++;
+         cat=old_index;
+         count++;
       } 
       pi_file_append_record(pf2, record, size, attr, cat, uid);
       idx++;
@@ -424,244 +426,244 @@ static void cb_edit_button(GtkWidget *widget, gpointer data)
    if (Pdata) {
       switch (button) {
        case EDIT_CAT_NEW:
-	 count=0;
-	 for (i=0; i<NUM_CATEGORIES-1; i++) {
-	    r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i, 0, &text);
-	    if ((r) && (text[0])) {
-	       count++;
-	    }
-	 }
-	 if (count>NUM_CATEGORIES-2) {
-	    dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
-			   _("Edit Categories"), DIALOG_ERROR,
-			   _("The maximum number of categories (16) are already used"), 1, button_text);
-	    return;
-	 }
-	 gtk_label_set_text(GTK_LABEL(Pdata->label), _("Enter New Category"));
-	 gtk_entry_set_text(GTK_ENTRY(Pdata->entry), "");
-	 gtk_widget_show(Pdata->entry_box);
-	 gtk_widget_hide(Pdata->button_box);
-	 gtk_widget_grab_focus(GTK_WIDGET(Pdata->entry));
-	 Pdata->state=EDIT_CAT_NEW;
-	 break;
+         count=0;
+         for (i=0; i<NUM_CATEGORIES-1; i++) {
+            r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i, 0, &text);
+            if ((r) && (text[0])) {
+               count++;
+            }
+         }
+         if (count>NUM_CATEGORIES-2) {
+            dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
+                           _("Edit Categories"), DIALOG_ERROR,
+                           _("The maximum number of categories (16) are already used"), 1, button_text);
+            return;
+         }
+         gtk_label_set_text(GTK_LABEL(Pdata->label), _("Enter New Category"));
+         gtk_entry_set_text(GTK_ENTRY(Pdata->entry), "");
+         gtk_widget_show(Pdata->entry_box);
+         gtk_widget_hide(Pdata->button_box);
+         gtk_widget_grab_focus(GTK_WIDGET(Pdata->entry));
+         Pdata->state=EDIT_CAT_NEW;
+         break;
 
        case EDIT_CAT_RENAME:
-	 if ((catnum<0) || (Pdata->cai2.name[catnum][0]=='\0')) {
-	    dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
-			   _("Edit Categories Error"), DIALOG_ERROR,
-			   _("You must select a category to rename"), 1, button_text);
-	    return;
-	 }
+         if ((catnum<0) || (Pdata->cai2.name[catnum][0]=='\0')) {
+            dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
+                           _("Edit Categories Error"), DIALOG_ERROR,
+                           _("You must select a category to rename"), 1, button_text);
+            return;
+         }
 #ifdef EDIT_CATS_DEBUG
- 	 if (catnum == 0) {
+         if (catnum == 0) {
             printf("Trying to rename category 0!\n");
          }
 #endif
-	 r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), Pdata->selected, 0, &text);
-	 gtk_label_set_text(GTK_LABEL(Pdata->label), _("Enter New Category Name"));
-	 gtk_entry_set_text(GTK_ENTRY(Pdata->entry), text);
-	 gtk_widget_show(Pdata->entry_box);
-	 gtk_widget_hide(Pdata->button_box);
-	 gtk_widget_grab_focus(GTK_WIDGET(Pdata->entry));
-	 Pdata->state=EDIT_CAT_RENAME;
-	 break;
+         r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), Pdata->selected, 0, &text);
+         gtk_label_set_text(GTK_LABEL(Pdata->label), _("Enter New Category Name"));
+         gtk_entry_set_text(GTK_ENTRY(Pdata->entry), text);
+         gtk_widget_show(Pdata->entry_box);
+         gtk_widget_hide(Pdata->button_box);
+         gtk_widget_grab_focus(GTK_WIDGET(Pdata->entry));
+         Pdata->state=EDIT_CAT_RENAME;
+         break;
 
        case EDIT_CAT_DELETE:
 #ifdef EDIT_CATS_DEBUG
-	 printf("delete cat\n");
+         printf("delete cat\n");
 #endif
-	 if (catnum<0) {
-	    dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
-			   _("Edit Categories Error"), DIALOG_ERROR,
-			   _("You must select a category to delete"), 1, button_text);
-	    return;
-	 }
+         if (catnum<0) {
+            dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
+                           _("Edit Categories Error"), DIALOG_ERROR,
+                           _("You must select a category to delete"), 1, button_text);
+            return;
+         }
 #ifdef EDIT_CATS_DEBUG
- 	 if (catnum == 0) {
+         if (catnum == 0) {
             printf("Trying to delete category 0!\n");
          }
 #endif
-	 /* Check if category is empty */
-	 if (Pdata->cai2.name[catnum][0]=='\0') {
-	    return;
-	 }
-	 /* Check to see if there are records are in this category */
- 	 count = count_records_in_cat(Pdata->db_name, catnum);
+         /* Check if category is empty */
+         if (Pdata->cai2.name[catnum][0]=='\0') {
+            return;
+         }
+         /* Check to see if there are records are in this category */
+         count = count_records_in_cat(Pdata->db_name, catnum);
 #ifdef EDIT_CATS_DEBUG
-	 printf("count=%d\n", count);
+         printf("count=%d\n", count);
 #endif
-	 if (count>0) {
-	    g_snprintf(temp, sizeof(temp), _("There are %d records in %s.\n"
-		       "Do you want to move them to %s, or delete them?"),
-		       count, Pdata->cai1.name[catnum], Pdata->cai1.name[0]);
-	    r = dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
-			       _("Edit Categories"), DIALOG_QUESTION,
-			       temp, 3, move_text);
-	    switch (r) {
-	     case DIALOG_SAID_1:
+         if (count>0) {
+            g_snprintf(temp, sizeof(temp), _("There are %d records in %s.\n"
+                       "Do you want to move them to %s, or delete them?"),
+                       count, Pdata->cai1.name[catnum], Pdata->cai1.name[0]);
+            r = dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
+                               _("Edit Categories"), DIALOG_QUESTION,
+                               temp, 3, move_text);
+            switch (r) {
+             case DIALOG_SAID_1:
 #ifdef EDIT_CATS_DEBUG
-	       printf("MOVE THEM\n");
+               printf("MOVE THEM\n");
 #endif
-	       r = edit_cats_change_cats_pc3(Pdata->db_name, catnum, 0);
+               r = edit_cats_change_cats_pc3(Pdata->db_name, catnum, 0);
 #ifdef EDIT_CATS_DEBUG
-	       printf("moved %d pc records\n", r);
+               printf("moved %d pc records\n", r);
 #endif
-	       r = edit_cats_change_cats_pdb(Pdata->db_name, catnum, 0);
+               r = edit_cats_change_cats_pdb(Pdata->db_name, catnum, 0);
 #ifdef EDIT_CATS_DEBUG
-	       printf("moved %d pdb->pc records\n", r);
+               printf("moved %d pdb->pc records\n", r);
 #endif
-	       break;
-	     case DIALOG_SAID_2:
+               break;
+             case DIALOG_SAID_2:
 #ifdef EDIT_CATS_DEBUG
-	       printf("DELETE THEM\n");
+               printf("DELETE THEM\n");
 #endif
-	       r = edit_cats_delete_cats_pc3(Pdata->db_name, catnum);
+               r = edit_cats_delete_cats_pc3(Pdata->db_name, catnum);
 #ifdef EDIT_CATS_DEBUG
-	       printf("deleted %d pc records\n", r);
+               printf("deleted %d pc records\n", r);
 #endif
-	       r = edit_cats_delete_cats_pdb(Pdata->db_name, catnum);
+               r = edit_cats_delete_cats_pdb(Pdata->db_name, catnum);
 #ifdef EDIT_CATS_DEBUG
-	       printf("deleted %d pdb->pc records\n", r);
+               printf("deleted %d pdb->pc records\n", r);
 #endif
-	       break;
-	     case DIALOG_SAID_3:
+               break;
+             case DIALOG_SAID_3:
 #ifdef EDIT_CATS_DEBUG
-	       printf("Delete Canceled\n");
+               printf("Delete Canceled\n");
 #endif
-	       return;
-	    }
-	 }
-	 /* delete the category */
+               return;
+            }
+         }
+         /* delete the category */
 #ifdef EDIT_CATS_DEBUG
-	 printf("DELETE category\n");
+         printf("DELETE category\n");
 #endif
-	 Pdata->cai2.name[catnum][0]='\0';
-	 Pdata->cai2.ID[catnum]=Pdata->cai1.ID[catnum];
-	 Pdata->cai2.renamed[catnum]=0;
-	 /* JPA move category names upward in listbox */
-	 /* we get the old text from listbox, to avoid making */
-	 /* character set conversions */
+         Pdata->cai2.name[catnum][0]='\0';
+         Pdata->cai2.ID[catnum]=Pdata->cai1.ID[catnum];
+         Pdata->cai2.renamed[catnum]=0;
+         /* JPA move category names upward in listbox */
+         /* we get the old text from listbox, to avoid making */
+         /* character set conversions */
          for (i=Pdata->selected; i<NUM_CATEGORIES-2; i++) {
-	    r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i+1, 0, &text);
+            r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i+1, 0, &text);
             if (r) gtk_clist_set_text(GTK_CLIST(Pdata->clist), i, 0, text);
-	 }
-	 /* JPA now clear the last category */
-	 gtk_clist_set_text(GTK_CLIST(Pdata->clist), NUM_CATEGORIES-2, 0, "");
-	 break;
+         }
+         /* JPA now clear the last category */
+         gtk_clist_set_text(GTK_CLIST(Pdata->clist), NUM_CATEGORIES-2, 0, "");
+         break;
 
        case EDIT_CAT_ENTRY_OK:
-	 if ((Pdata->state!=EDIT_CAT_RENAME) && (Pdata->state!=EDIT_CAT_NEW)) {
-	    jp_logf(JP_LOG_WARN, _("invalid state file %s line %d\n"), __FILE__, __LINE__);
-	    return;
-	 }
-	 entry_text = gtk_entry_get_text(GTK_ENTRY(Pdata->entry));
+         if ((Pdata->state!=EDIT_CAT_RENAME) && (Pdata->state!=EDIT_CAT_NEW)) {
+            jp_logf(JP_LOG_WARN, _("invalid state file %s line %d\n"), __FILE__, __LINE__);
+            return;
+         }
+         entry_text = gtk_entry_get_text(GTK_ENTRY(Pdata->entry));
 
-	 /* Can't make an empty category, could do a dialog telling user */
-	 if ((!entry_text) || (!entry_text[0])) {
-	    return;
-	 }
+         /* Can't make an empty category, could do a dialog telling user */
+         if ((!entry_text) || (!entry_text[0])) {
+            return;
+         }
 
- 	 if ((Pdata->state==EDIT_CAT_RENAME) || (Pdata->state==EDIT_CAT_NEW)) {
-	    /* Check for category being used more than once */
-	    /* moved here by JPA for use in both new and rename cases */
-	    /* JPA convert entry to Pilot character set before checking */
-	    /* note : don't know Pilot size until converted */
-	    g_strlcpy(pilotentry, entry_text, HOSTCAT_NAME_SZ);
-	    charset_j2p(pilotentry, HOSTCAT_NAME_SZ, char_set);
-	    pilotentry[PILOTCAT_NAME_SZ-1] = '\0';
-	    for (i=0; i<NUM_CATEGORIES; i++) {
-	       /* JPA allow a category to be renamed to its previous name */
-	       if (((i != catnum) || (Pdata->state != EDIT_CAT_RENAME))
-		   && !strcmp(pilotentry, Pdata->cai2.name[i])) {
-		  sprintf(temp, _("The category %s can't be used more than once"), entry_text);
-		  dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
-				 _("Edit Categories"), DIALOG_ERROR,
-				 temp, 1, button_text);
-		  return;
-	       }
-	    }
-	 }
-	 if (Pdata->state==EDIT_CAT_RENAME) {
+         if ((Pdata->state==EDIT_CAT_RENAME) || (Pdata->state==EDIT_CAT_NEW)) {
+            /* Check for category being used more than once */
+            /* moved here by JPA for use in both new and rename cases */
+            /* JPA convert entry to Pilot character set before checking */
+            /* note : don't know Pilot size until converted */
+            g_strlcpy(pilotentry, entry_text, HOSTCAT_NAME_SZ);
+            charset_j2p(pilotentry, HOSTCAT_NAME_SZ, char_set);
+            pilotentry[PILOTCAT_NAME_SZ-1] = '\0';
+            for (i=0; i<NUM_CATEGORIES; i++) {
+               /* JPA allow a category to be renamed to its previous name */
+               if (((i != catnum) || (Pdata->state != EDIT_CAT_RENAME))
+                   && !strcmp(pilotentry, Pdata->cai2.name[i])) {
+                  sprintf(temp, _("The category %s can't be used more than once"), entry_text);
+                  dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
+                                 _("Edit Categories"), DIALOG_ERROR,
+                                 temp, 1, button_text);
+                  return;
+               }
+            }
+         }
+         if (Pdata->state==EDIT_CAT_RENAME) {
 #ifdef EDIT_CATS_DEBUG
-	    printf("rename cat\n");
+            printf("rename cat\n");
 #endif
-	    i=Pdata->selected;
-	    /* JPA assuming gtk makes a copy */
-	    gtk_clist_set_text(GTK_CLIST(Pdata->clist), i, 0, entry_text);
-	    /* JPA enter new category name in Palm Pilot character set */
-	    charset_j2p((char *)entry_text, HOSTCAT_NAME_SZ, char_set);
-	    g_strlcpy(Pdata->cai2.name[catnum], entry_text, PILOTCAT_NAME_SZ);
-	    Pdata->cai2.renamed[catnum]=1;
-	 }
+            i=Pdata->selected;
+            /* JPA assuming gtk makes a copy */
+            gtk_clist_set_text(GTK_CLIST(Pdata->clist), i, 0, entry_text);
+            /* JPA enter new category name in Palm Pilot character set */
+            charset_j2p((char *)entry_text, HOSTCAT_NAME_SZ, char_set);
+            g_strlcpy(Pdata->cai2.name[catnum], entry_text, PILOTCAT_NAME_SZ);
+            Pdata->cai2.renamed[catnum]=1;
+         }
 
-	 if (Pdata->state==EDIT_CAT_NEW) {
+         if (Pdata->state==EDIT_CAT_NEW) {
 #ifdef EDIT_CATS_DEBUG
-	    printf("new cat\n");
+            printf("new cat\n");
 #endif
-	    /* JPA have already checked category is not being used more than once */
-	    /* Find a new category ID */
-	    id=128;
-	    for (i=1; i<NUM_CATEGORIES; i++) {
-	       if (Pdata->cai2.ID[i]==id) {
-		  id++;
-		  i=1;
-	       }
-	    }
-	    /* Find an empty slot */
-	    /* When the new button was pressed we already checked for an empty slot */
-	    for (i=1; i<NUM_CATEGORIES; i++) {
-	       if (Pdata->cai2.name[i][0]=='\0') {
+            /* JPA have already checked category is not being used more than once */
+            /* Find a new category ID */
+            id=128;
+            for (i=1; i<NUM_CATEGORIES; i++) {
+               if (Pdata->cai2.ID[i]==id) {
+                  id++;
+                  i=1;
+               }
+            }
+            /* Find an empty slot */
+            /* When the new button was pressed we already checked for an empty slot */
+            for (i=1; i<NUM_CATEGORIES; i++) {
+               if (Pdata->cai2.name[i][0]=='\0') {
 #ifdef EDIT_CATS_DEBUG
-		  printf("slot %d is empty\n", i);
+                  printf("slot %d is empty\n", i);
 #endif
-		  /* JPA get the old text from listbox, to avoid making */
-		  /* character set conversions */
-	          r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i-1, 0, &text);
+                  /* JPA get the old text from listbox, to avoid making */
+                  /* character set conversions */
+                  r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i-1, 0, &text);
                   if (r)
-		     g_strlcpy(currentname, text, HOSTCAT_NAME_SZ);
-		  strcpy(Pdata->cai2.name[i], pilotentry);
-		  Pdata->cai2.ID[i]=id;
-		  Pdata->cai2.renamed[i]=1;
-		  gtk_clist_set_text(GTK_CLIST(Pdata->clist), i-1, 0, entry_text);
-		  /* JPA relabel category labels beyond the change */
+                     g_strlcpy(currentname, text, HOSTCAT_NAME_SZ);
+                  strcpy(Pdata->cai2.name[i], pilotentry);
+                  Pdata->cai2.ID[i]=id;
+                  Pdata->cai2.renamed[i]=1;
+                  gtk_clist_set_text(GTK_CLIST(Pdata->clist), i-1, 0, entry_text);
+                  /* JPA relabel category labels beyond the change */
                   j = ++i;
                   while (r && (i < NUM_CATEGORIES)) {
-		     while ((j < NUM_CATEGORIES) && (Pdata->cai2.name[j][0] == '\0')) j++;
+                     while ((j < NUM_CATEGORIES) && (Pdata->cai2.name[j][0] == '\0')) j++;
                      if (j < NUM_CATEGORIES) {
                         strcpy(previousname, currentname);
-			r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i-1, 0, &text);
+                        r = gtk_clist_get_text(GTK_CLIST(Pdata->clist), i-1, 0, &text);
                         if (r)
-			   g_strlcpy(currentname, text, HOSTCAT_NAME_SZ);
-		        gtk_clist_set_text(GTK_CLIST(Pdata->clist), i-1, 0, previousname);
+                           g_strlcpy(currentname, text, HOSTCAT_NAME_SZ);
+                        gtk_clist_set_text(GTK_CLIST(Pdata->clist), i-1, 0, previousname);
                         j++;
-		     }
+                     }
                      i++;
-		  }
-		  break;
-	       }
-	    }
-	 }
-	 gtk_widget_hide(Pdata->entry_box);
-	 gtk_widget_show(Pdata->button_box);
-	 Pdata->state=EDIT_CAT_START;
-	 break;
+                  }
+                  break;
+               }
+            }
+         }
+         gtk_widget_hide(Pdata->entry_box);
+         gtk_widget_show(Pdata->button_box);
+         Pdata->state=EDIT_CAT_START;
+         break;
 
        case EDIT_CAT_ENTRY_CANCEL:
-	 gtk_widget_hide(Pdata->entry_box);
-	 gtk_widget_show(Pdata->button_box);
-	 Pdata->state=EDIT_CAT_START;
-	 break;
+         gtk_widget_hide(Pdata->entry_box);
+         gtk_widget_show(Pdata->button_box);
+         Pdata->state=EDIT_CAT_START;
+         break;
 
        default:
-	 jp_logf(JP_LOG_WARN, "cb_edit_button(): %s\n", "unknown button");
+         jp_logf(JP_LOG_WARN, "cb_edit_button(): %s\n", "unknown button");
       }
    }
 }
 
 
 static void cb_clist_edit_cats(GtkWidget *widget,
-			gint row, gint column,
-			GdkEventButton *event, gpointer data)
+                               gint row, gint column,
+                               GdkEventButton *event, gpointer data)
 {
    struct dialog_cats_data *Pdata;
 
@@ -677,7 +679,7 @@ static void cb_clist_edit_cats(GtkWidget *widget,
       printf("cb_clist_edit_cats not in start state\n");
 #endif
       if (Pdata->selected!=row) {
-	 clist_select_row(GTK_CLIST(Pdata->clist), Pdata->selected, 0);
+         clist_select_row(GTK_CLIST(Pdata->clist), Pdata->selected, 0);
       }
    }
 }
@@ -691,8 +693,8 @@ static void cb_edit_cats_debug(GtkWidget *widget, gpointer data)
    Pdata=data;
    for (i=0; i<NUM_CATEGORIES; i++) {
       printf("cai %2d [%16s] ID %3d %d: [%16s] ID %3d %d\n", i,
-	     Pdata->cai1.name[i], Pdata->cai1.ID[i], Pdata->cai1.renamed[i],
-	     Pdata->cai2.name[i], Pdata->cai2.ID[i], Pdata->cai2.renamed[i]);
+             Pdata->cai1.name[i], Pdata->cai1.ID[i], Pdata->cai1.renamed[i],
+             Pdata->cai2.name[i], Pdata->cai2.ID[i], Pdata->cai2.renamed[i]);
    }
 }
 #endif
@@ -741,8 +743,8 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
 #ifdef EDIT_CATS_DEBUG
    for (i = 0; i < NUM_CATEGORIES; i++) {
       if (cai->name[i][0] != '\0') {
-	 printf("cat %d [%s] ID %d renamed %d\n", i, cai->name[i],
-		cai->ID[i], cai->renamed[i]);
+         printf("cat %d [%s] ID %d renamed %d\n", i, cai->name[i],
+                cai->ID[i], cai->renamed[i]);
       }
    }
 #endif
@@ -754,18 +756,18 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
  *   get_pref(PREF_CHAR_SET, &char_set, NULL);
  *   if (char_set != CHAR_SET_LATIN1) {
  *      for (i = 0; i < 16; i++) {
- *	 if (cai->name[i][0] != '\0') {
- *	    charset_p2j((unsigned char*)cai->name[i], 16, char_set);
- *	 }
+ *       if (cai->name[i][0] != '\0') {
+ *          charset_p2j((unsigned char*)cai->name[i], 16, char_set);
+ *       }
  *      }
  *   }
  *
  */
 
    dialog = gtk_widget_new(GTK_TYPE_WINDOW,
-			   "type", GTK_WINDOW_TOPLEVEL,
-			   "title", _("Edit Categories"),
-			   NULL);
+                           "type", GTK_WINDOW_TOPLEVEL,
+                           "title", _("Edit Categories"),
+                           NULL);
 
    gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
    gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
@@ -795,7 +797,7 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_BROWSE);
 
    gtk_signal_connect(GTK_OBJECT(clist), "select_row",
-		      GTK_SIGNAL_FUNC(cb_clist_edit_cats), &Pdata);
+                      GTK_SIGNAL_FUNC(cb_clist_edit_cats), &Pdata);
    gtk_box_pack_start(GTK_BOX(vbox1), clist, TRUE, TRUE, 1);
 
    /* Fill clist with categories except for category 0, Unfiled,
@@ -805,16 +807,16 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
       gtk_clist_append(GTK_CLIST(clist), empty_line);
       /* Hide void category names */
       while ((j < NUM_CATEGORIES) && ((cai->name[j][0] == '\0') || (!cai->ID[j]))) {
-	 /* Remove categories which have a null ID 
+         /* Remove categories which have a null ID 
           * to facilitate recovering from errors, */
-	 /* however we cannot synchronize them to the Palm Pilot */
+         /* however we cannot synchronize them to the Palm Pilot */
          if (!cai->ID[j]) cai->name[j][0] = '\0';
          j++;
       }
       if (j < NUM_CATEGORIES) {
           /* Must do character set conversion from Palm to Host */
           catname_hchar = charset_p2newj(cai->name[j], PILOTCAT_NAME_SZ, char_set);
-	  gtk_clist_set_text(GTK_CLIST(clist), i-1, 0, catname_hchar);
+          gtk_clist_set_text(GTK_CLIST(clist), i-1, 0, catname_hchar);
           free(catname_hchar);
       }
    }
@@ -834,14 +836,14 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
    button = gtk_button_new_with_label(_("New"));
 #endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_edit_button),
-		      GINT_TO_POINTER(EDIT_CAT_NEW));
+                      GTK_SIGNAL_FUNC(cb_edit_button),
+                      GINT_TO_POINTER(EDIT_CAT_NEW));
    gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 1);
 
    button = gtk_button_new_with_label(_("Rename"));
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_edit_button),
-		      GINT_TO_POINTER(EDIT_CAT_RENAME));
+                      GTK_SIGNAL_FUNC(cb_edit_button),
+                      GINT_TO_POINTER(EDIT_CAT_RENAME));
    gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 1);
 
 #ifdef ENABLE_STOCK_BUTTONS
@@ -850,8 +852,8 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
    button = gtk_button_new_with_label(_("Delete"));
 #endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_edit_button),
-		      GINT_TO_POINTER(EDIT_CAT_DELETE));
+                      GTK_SIGNAL_FUNC(cb_edit_button),
+                      GINT_TO_POINTER(EDIT_CAT_DELETE));
    gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 1);
 
    Pdata.button_box = hbox;
@@ -870,8 +872,8 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
 
    entry = gtk_entry_new_with_max_length(HOSTCAT_NAME_SZ-1);
    gtk_signal_connect(GTK_OBJECT(entry), "activate",
-		      GTK_SIGNAL_FUNC(cb_edit_button),
-		      GINT_TO_POINTER(EDIT_CAT_ENTRY_OK));
+                      GTK_SIGNAL_FUNC(cb_edit_button),
+                      GINT_TO_POINTER(EDIT_CAT_ENTRY_OK));
    gtk_box_pack_start(GTK_BOX(vbox), entry, FALSE, FALSE, 0);
 
    hbox = gtk_hbutton_box_new();
@@ -881,14 +883,14 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 1);
    button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_edit_button),
-		      GINT_TO_POINTER(EDIT_CAT_ENTRY_CANCEL));
+                      GTK_SIGNAL_FUNC(cb_edit_button),
+                      GINT_TO_POINTER(EDIT_CAT_ENTRY_CANCEL));
    gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 1);
 
    button = gtk_button_new_from_stock(GTK_STOCK_OK);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_edit_button),
-		      GINT_TO_POINTER(EDIT_CAT_ENTRY_OK));
+                      GTK_SIGNAL_FUNC(cb_edit_button),
+                      GINT_TO_POINTER(EDIT_CAT_ENTRY_OK));
    gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 1);
 
    separator = gtk_hseparator_new();
@@ -907,20 +909,20 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
    /* Buttons */
    button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_dialog_button),
-		      GINT_TO_POINTER(DIALOG_SAID_2));
+                      GTK_SIGNAL_FUNC(cb_dialog_button),
+                      GINT_TO_POINTER(DIALOG_SAID_2));
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 1);
 
    button = gtk_button_new_from_stock(GTK_STOCK_OK);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_dialog_button),
-		      GINT_TO_POINTER(DIALOG_SAID_1));
+                      GTK_SIGNAL_FUNC(cb_dialog_button),
+                      GINT_TO_POINTER(DIALOG_SAID_1));
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 1);
 
 #ifdef EDIT_CATS_DEBUG
    button = gtk_button_new_with_label("DEBUG");
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_edit_cats_debug), &Pdata);
+                      GTK_SIGNAL_FUNC(cb_edit_cats_debug), &Pdata);
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 1);
 #endif
 
@@ -951,8 +953,8 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai)
 #ifdef EDIT_CATS_DEBUG
    for (i=0; i<NUM_CATEGORIES; i++) {
       printf("name %d [%s] ID %d [%s] ID %d\n", i,
-			 Pdata.cai1.name[i], Pdata.cai1.ID[i],
-			 Pdata.cai2.name[i], Pdata.cai2.ID[i]);
+                         Pdata.cai1.name[i], Pdata.cai1.ID[i],
+                         Pdata.cai2.name[i], Pdata.cai2.ID[i]);
    }
 #endif
 
